@@ -41,14 +41,20 @@ sub _parse_fields {
         }
 
         my $v = shift @fields;
-        my @values = ( ref $v and !blessed $v ) ? @$v : ( "$v" );
+        my @values = ( ref $v and !blessed $v ) ? @$v : $v;
         push @new_fields,
-            map { WebService::Solr::Field->new( $f => $_ ) } @values;
+            map { WebService::Solr::Field->new( $f => "$_" ) } @values;
     }
 
     return @new_fields;
 }
 
+sub field_names {
+    my ( $self ) = @_;
+    my %names = map { $_->name => 1 } $self->fields;
+    return keys %names;
+}
+
 sub value_for {
     my @values = shift->values_for( shift );
     return $values[ 0 ];
@@ -118,6 +124,10 @@ A Moose override to allow our custom constructor.
 
 Adds C<@fields> to the document.
 
+=head2 field_names
+
+Returns a list of field names that are in this document.
+
 =head2 value_for( $name )
 
 Returns the first value for C<$name>.
@@ -134,11 +144,11 @@ Serializes the object to xml.
 
 Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
-Kirk Beers E<lt>kirk.beers@nald.caE<gt>
+Kirk Beers
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2009 National Adult Literacy Database
+Copyright 2008-2011 National Adult Literacy Database
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
